from typing import List, Optional

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.job_title import JobTitle
from app.schemas.job_title import JobTitleCreate, JobTitleUpdate


class CRUDJobTitle(CRUDBase[JobTitle, JobTitleCreate, JobTitleUpdate]):
    def get_by_title(self, db: Session, *, title: str) -> Optional[JobTitle]:
        return db.query(JobTitle).filter(JobTitle.title == title).first()
    
    def get_all(self, db: Session) -> List[JobTitle]:
        return db.query(JobTitle).all()


job_title = CRUDJobTitle(JobTitle)